<?php /*

**************************************************************************

Plugin Name:  Dashboard: Draft Posts
Plugin URI:   http://www.viper007bond.com/wordpress-plugins/dashboard-draft-posts/
Description:  Displays draft posts on your WordPress 2.5+ dashboard.
Version:      1.0.3
Author:       Viper007Bond
Author URI:   http://www.viper007bond.com/

**************************************************************************/

class DashboardDraftPosts {

	// Class initialization
	function DashboardDraftPosts() {
		if ( !current_user_can( 'edit_posts' ) ) return;

		// Load up the localization file if we're using WordPress in a different language
		// Place it in this plugin's folder and name it "dashboard-draft-posts-[value in wp-config].mo"
		load_plugin_textdomain( 'dashboard-draft-posts', '/wp-content/plugins/dashboard-draft-posts' );

		// Add the widget to the dashboard
		add_action( 'wp_dashboard_setup', array(&$this, 'register_widget') );
		add_filter( 'wp_dashboard_widgets', array(&$this, 'add_widget') );
	}


	// Register this widget -- we use a hook/function to make the widget a dashboard-only widget
	function register_widget() {
		wp_register_sidebar_widget( 'dashboard_draft_posts', __( 'Draft Posts', 'dashboard-draft-posts' ), array(&$this, 'widget'), array( 'all_link' => 'edit.php?post_status=draft' ) );
	}


	// Modifies the array of dashboard widgets and adds this plugin's
	function add_widget( $widgets ) {
		global $wp_registered_widgets;

		if ( !isset($wp_registered_widgets['dashboard_draft_posts']) ) return $widgets;

		array_splice( $widgets, 2, 0, 'dashboard_draft_posts' );

		return $widgets;
	}


	// Output the widget contents
	function widget( $args ) {
		extract( $args, EXTR_SKIP );

		echo $before_widget;

		echo $before_title;
		echo $widget_name;
		echo $after_title;

		global $wpdb, $post;

		$posts = $wpdb->get_results( "SELECT * FROM $wpdb->posts WHERE post_status = 'draft' AND ( post_type = 'post' OR post_type = 'page' ) ORDER BY post_modified DESC LIMIT 25" );

		if ( $posts ) {
			echo "<ul>\n";
			foreach ( $posts as $post ) {
				setup_postdata( $post );

				$time = get_post_modified_time('G', true);

				if ( ( abs(time() - $time) ) < 86400 )
					$h_time = sprintf( __('%s ago'), human_time_diff( $time ) );
				else
					$h_time = mysql2date(__('Y/m/d'), $post->post_modified);


				$posttitle = get_the_title();
				if ( empty($posttitle) )
					$posttitle = __('(no title)');

				$title = ( current_user_can( 'edit_post', $post->ID ) ) ? '<a href="post.php?action=edit&amp;post=' . $post->ID . '">' . $posttitle . '</a>' : '<span style="text-decoration:underline">' . $posttitle . '</span>';

				echo '	<li>' . sprintf( __('%s by %s &#8212; Updated %s', 'dashboard-draft-posts'), $title, '<strong>' . get_the_author() . '</strong>', '<abbr title="' . get_the_modified_time(__('Y/m/d g:i:s A')) . '">' . $h_time . '</abbr>' ) . "</li>\n";
			}
			echo "</ul>\n";
		} else {
			echo '<p>' . __("There are no drafts to show.", 'dashboard-draft-posts') . "</p>\n";
		}

		echo $after_widget;
	}
}

// Start this plugin once all other plugins are fully loaded
add_action( 'plugins_loaded', create_function( '', 'global $DashboardDraftPosts; $DashboardDraftPosts = new DashboardDraftPosts();' ) );

?>